SPM12
=====

|Tests|

Thin Python wrappers around `Statistical Parametric Mapping <https://www.fil.ion.ucl.ac.uk/spm>`_.


Install
-------

.. code:: sh

    pip install -U spm12


.. |Tests| image:: https://img.shields.io/github/workflow/status/AMYPAD/SPM12/Test
   :target: https://github.com/AMYPAD/SPM12/actions
